<?php
/**
 * WG Piccolo Theme functions and definitions
 *
 * @package WG Piccolo Theme
 */

if ( ! function_exists( 'wgpiccolo_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function wgpiccolo_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on WG Piccolo Theme, use a find and replace
	 * to change 'wgpiccolo' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'wgpiccolo', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );
	add_editor_style();
	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'post-thumb', 770,300, true );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Header Menu', 'wgpiccolo' ),
		'footer' => esc_html__( 'Footer Menu', 'wgpiccolo' ),
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'wgpiccolo_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => get_template_directory_uri(). '/img/page-bg-1.jpg',
	) ) );
}
endif; // wgpiccolo_setup

// Content Width
if ( ! isset( $content_width ) ) {
	$content_width = 770;
}

add_action( 'after_setup_theme', 'wgpiccolo_setup' );

function wgpiccolo_default_menu(){
	echo '<ul class="nav">';
	echo '<li><a href="'.esc_url(home_url()).'">'.__('Home' , 'wgpiccolo').'</a></li>';
	echo '</ul>';
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */


/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function wgpiccolo_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'wgpiccolo' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<ul class="single-widget post-category-list">',
		'after_widget'  => '</ul>',
		'before_title'  => '<h5 class="title-bg">',
		'after_title'   => '</h5>',
	) );	
}
add_action( 'widgets_init', 'wgpiccolo_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
 
function htmlsupport(){ ?>
	<!--[if lt IE 9]>
		<script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
		<link rel="stylesheet" href="css/style-ie.css"/>
	<![endif]--> 
<?php }
add_action('wp_head' , 'htmlsupport');

function wgpiccolo_scripts() {
	wp_enqueue_style('google-font', '//fonts.googleapis.com/css?family=Oswald');
	wp_enqueue_style('google-font-pacifico', '//fonts.googleapis.com/css?family=Yellowtail');
	wp_enqueue_style('font-awosome', get_template_directory_uri() .  '/css/font-awesome.css');
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/css/bootstrap.css');
	wp_enqueue_style('bootstrap-responsive', get_template_directory_uri() . '/css/bootstrap-responsive.css');
	wp_enqueue_style('custom-styles', get_template_directory_uri() . '/css/custom-styles.css');	
	wp_enqueue_style( 'wgpiccolo-style', get_stylesheet_uri() );
	
	wp_enqueue_script('jquery');
	wp_enqueue_script( 'wgpiccolo-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );
	wp_enqueue_script( 'wgpiccolo-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array(), '20130117', true );
	wp_enqueue_script( 'jflickrfeed.min-js', get_template_directory_uri() . '/js/jflickrfeed.min.js', array(), '20130118', true );
	wp_enqueue_script( 'tweecool.min.js', get_template_directory_uri() . '/js/tweecool.min.js', array(), '201301120', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'wgpiccolo_scripts' );
function wgpiccolo_activejs(){ ?>
<script type="text/javascript">
jQuery(document).ready(function(){

	jQuery('.img-feed').jflickrfeed({
		limit: 12,
		qstrings: {
			id: '<?php echo get_theme_mod('flickr_image'); ?>'
		},
		itemTemplate: '<li><a href="{{image_b}}"><img src="{{image_s}}" alt="{{title}}" /></a></li>'
	});	
	jQuery('#tweecool').tweecool({
		// Your twitter username
		username : '<?php echo get_theme_mod('tatest_tweets'); ?>',

		// Number of tweets to show
		limit : 3, 

		// Show profile image
		profile_image : false, 

		// Show tweet time
		show_time : true, 

		// Show media
		show_media : false,

		//values: small, large, thumb, medium 
		show_media_size: 'thumb'  
		});
});
</script>
<?php }
add_action('wp_footer' , 'wgpiccolo_activejs');


/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
require get_template_directory() . '/inc/comments-style.php';

// comment list modify
function wg_piccolo_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

	<article class="comment-body">
		 <?php echo get_avatar( $comment, 83 ); ?>
		 <span class="comment-name"><?php comment_author_link(); ?></span>
		<span class="comment-date"> <i class="fa fa-clock-o"></i> <?php comment_date('F j, Y'); ?> | <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))); ?></span>
		<?php if ($comment->comment_approved == '0') : ?>
			<p><em><?php _e('Your comment is awaiting moderation.','wgpiccolo'); ?></em></p>
		<?php endif; ?>
		
		<div class="comment-content">	
			<?php comment_text(); ?>
		</div>

	</article>	
</li>


<?php } 

// Replay modify
function wg_piccolo_comment_reform ($arg) {

$arg['title_reply'] = __('<i class="fa fa-comment"></i> Leave a Comment','wgpiccolo');
$arg['comment_field'] = '<textarea id="comment" class="span6" name="comment" cols="77" rows="8" placeholder="'. __("Comment", "wgpiccolo").'" aria-required="true"></textarea>';


return $arg;

}
add_filter('comment_form_defaults','wg_piccolo_comment_reform');

// comment form modify

function wg_piccolo_modify_comment_form_fields($fields){
	$commenter = wp_get_current_commenter();
	$req	   = get_option( 'require_name_email' );

	$fields['author'] = '<div class="input-prepend"><span class="add-on"><i class="icon-user"></i></span><input type="text" name="author" id="author" value="'. esc_attr( $commenter['comment_author'] ) .'" placeholder="'. __("Your Name *", "wgpiccolo").'" size="22" tabindex="1"'. ( $req ? 'aria-required="true"' : '' ).' class="input-name span4" /></div>';

	$fields['email'] = '<div class="input-prepend"><span class="add-on"><i class="icon-envelope"></i></span><input type="text" name="email" id="email" value="'. esc_attr( $commenter['comment_author_email'] ) .'" placeholder="'. __("Your Email *", "wgpiccolo").'" size="22" tabindex="2"'. ( $req ? 'aria-required="true"' : '' ).' class="input-email span4"  /></div>';
	
	$fields['url'] = '<div class="input-prepend"><span class="add-on"><i class="icon-globe"></i></span><input type="text" name="url" id="url" value="'. esc_attr( $commenter['comment_author_url'] ) .'" placeholder="'. __("Website", "wgpiccolo").'" size="22" tabindex="2"'. ( $req ? 'aria-required="false"' : '' ).' class="input-url span4"  /></div>';

	return $fields;
}
add_filter('comment_form_default_fields','wg_piccolo_modify_comment_form_fields');